import { Reducer as ReduxReducer, AnyAction } from 'redux';
import { ChainedPod, ActionSet, ExposedActionSet } from './interfaces';
import { FunctionProducer } from './function_producer';
import { PodMethods } from './methods';
import { PodProperties } from './properties';
/**
 * The root pod reducer class as a `FunctionProducer`. The main purpose of this class is
 * to initialize the root reducer function as a handle for incoming internal actions and to
 * propagate the incoming state/action objects through the stateful effect chain.
 *
 * It's also responsible for binding the root reducer function with the external methods
 * provided by the `PodMethods` class, along with the proxied action creators chained onto
 * the pod.
 *
 * Used by the root `pod` function to instantiate new pod instances.
 */
export declare class PodReducer<S, A extends ActionSet<S>> extends FunctionProducer<ExposedActionSet<A> & PodMethods<S, A>, ReduxReducer<S>> {
    private props;
    /**
     * Pod reducer class constructor providing the root reducer function to the
     * function producer super class.
     *
     * @param props The initial or chained `PodProperties` object.
     */
    constructor(props: PodProperties<any, any>);
    /**
     * The first action handler method for all incoming actions. Checks for internal
     * actions, a match on any of the proxied actions and otherwise propagates a drafted
     * state obj. and the incoming action through the stateful effect chain.
     *
     * @param state The incoming state obj. from the redux store.
     * @param action The incoming action obj.
     */
    handleAction(state: S, action: AnyAction): any;
    /**
     * Retreives the `PodProperties` obj. corresponding to the pod reducer.
     */
    getProps(): PodProperties<S, A>;
    /**
     * Chains the reducer with a new reducer instance with an updated set of properties.
     *
     * @param propsToMerge A partial property obj. to merge into the chained instance.
     */
    chain<ChainedState, ChainedActionSet extends ActionSet<ChainedState>>(propsToMerge?: Partial<PodProperties<any, any>>): ChainedPod<ChainedState, ChainedActionSet>;
    /**
     * Provies an obj. of bound `PodMethods` members along with external proxied action
     * handlers to the super `FunctionProducer` class, which is then applied directly
     * to the root reducer funuction.
     */
    boundFunctionMembers(): ExposedActionSet<A> & PodMethods<S, A>;
}
